@@ -174,6 +174,12 @@ class Database(core.Construct):
             and isinstance(database_will_send_email, str)
             and database_will_send_email.lower() == "true"
         )
+
+        self._instance = None
+        self._cluster = None
+        self._rds_security_group = None
+
+
         # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ Validate input params
 
         # TODO
