@@ -101,6 +101,8 @@ class Microservice(core.Construct):
 
         will_use_efs (str): Wether or not should create a EFS
 
+        will_use_cdn (str): Wether or not the Application Load Balancer should receive traffic only from Cloudflare CDN
+
     """
 
     @property
@@ -270,17 +272,20 @@ class Microservice(core.Construct):
 
         return tg
 
-    def create_load_balancer(self, scope, id, app_name, environment, security_group, internet_facing=False, load_balancer_name=None):
+    def create_load_balancer(self, scope, id, app_name, environment, environments_parameters, security_group=None, internet_facing=False, load_balancer_name=None, use_cdn=False):
         """Create a Load Balancer resource
         
         Args:
             id (str): the logical id of the newly created resource
 
-            security_group (aws_ec2.SecurityGroup): The security group to configure to enable access from FAO network
+            security_group (Optional | [aws_ec2.SecurityGroup]): The security group to configure to enable access from FAO network
 
             internet_facing (str): if the load balancer should be internet-facing or not
 
             load_balancer_name (str): the load balancer name
+
+            use_cdn (bool): if the Application Load Balancer should accept traffic only from CDN. If this is set to True, the `
+            _group` parameter will be ignored
     
         Returns:
             aws_alb.ApplicationLoadBalancer: the newly created Load Balancer
@@ -288,6 +293,61 @@ class Microservice(core.Construct):
         if load_balancer_name is None:
             load_balancer_name = id
 
+        # Always 
+        if use_cdn:
+
+            cdn_security_group = self.create_security_group(
+                self, 
+                "alb_sg_cdn", 
+                app_name, 
+                environment, 
+                app_name + "_alb_sg_cdn"
+                )
+
+            # Cloudflare doc https://support.cloudflare.com/hc/en-us/articles/360037983412-Configuring-an-Amazon-Web-Services-static-site-to-use-Cloudflare
+            cloudflare_ips_v4 = [
+                "103.21.244.0/22",
+                "103.22.200.0/22",
+                "103.31.4.0/22",
+                "104.16.0.0/12",
+                "108.162.192.0/18",
+                "131.0.72.0/22",
+                "141.101.64.0/18",
+                "162.158.0.0/15",
+                "172.64.0.0/13",
+                "173.245.48.0/20",
+                "188.114.96.0/20",
+                "190.93.240.0/20",
+                "197.234.240.0/22",
+                "198.41.128.0/17",
+            ]
+            for ip in cloudflare_ips_v4:
+                cdn_security_group.add_ingress_rule(                
+                    peer=_ec2.Peer.ipv4(ip),
+                    connection=self._tcp_connection_traffic_port,
+                    description="Cloudflare ipv4",
+                    )     
+
+            # Cloudflare doc https://support.cloudflare.com/hc/en-us/articles/360037983412-Configuring-an-Amazon-Web-Services-static-site-to-use-Cloudflare
+            cloudflare_ips_v6 = [
+                "2400:cb00::/32",
+                "2405:8100::/32",
+                "2405:b500::/32",
+                "2606:4700::/32",
+                "2803:f800::/32",
+                "2c0f:f248::/32",
+                "2a06:98c0::/29",
+            ]
+
+            for ip in cloudflare_ips_v6:
+                cdn_security_group.add_ingress_rule(                
+                    peer=_ec2.Peer.ipv6(ip),
+                    connection=self._tcp_connection_traffic_port,
+                    description="Cloudflare ipv6",
+                    )     
+
+            security_group = cdn_security_group
+
         alb = _alb.ApplicationLoadBalancer(
             scope,
             id,
@@ -429,7 +489,7 @@ class Microservice(core.Construct):
         ec2_traffic_port=None,
         upstream_security_group=None,
         ec2_health_check_path=None,
-        user_data_s3_key=None,
+        user_data_s3_key="user-data.sh",
         downstream_security_group=None,
         downstream_port=None,
         ssl_certificate_arn=None,
@@ -437,6 +497,7 @@ class Microservice(core.Construct):
         ebs_volume_size=None,
         ebs_snapshot_id=None,
         will_use_efs=False,
+        will_use_cdn=False,
         access_log_bucket_name="fao-elb-logs",
         authorization_endpoint=None,
         token_endpoint=None,
@@ -489,6 +550,10 @@ class Microservice(core.Construct):
         )
         is_not_ha = not is_ha
 
+        use_cdn = (
+            will_use_cdn and isinstance(will_use_cdn, str) and will_use_cdn.lower() == "true"
+        )
+        
         use_ebs = not not ebs_volume_size
         create_ebs = use_ebs and is_not_ha
 
@@ -664,7 +729,15 @@ class Microservice(core.Construct):
         # Elastic Load Balancer v2
         # ~~~~~~~~~~~~~~~~
         self.alb = self.create_load_balancer(
-            self, "alb", app_name, environment, self.alb_security_group, internet_facing=is_public, load_balancer_name='-'.join([app_name, main_component_name, 'alb'])
+            self, 
+            "alb", 
+            app_name, 
+            environment, 
+            environments_parameters, 
+            self.alb_security_group, 
+            internet_facing=is_public, 
+            load_balancer_name='-'.join([app_name, main_component_name, 'alb']), 
+            use_cdn=use_cdn
         )
 
         # Listeners
