@@ -301,10 +301,21 @@ class ServiceUserForIAC(core.Construct):
                     ),
                 ],
             )
-        
-                # S3 Code bucket permissions
+    
+        # Service user
+        self._service_user = _iam.User(
+            self,
+            "service_user",
+            managed_policies=[
+                managed_policy_for_iac,
+                managed_policy_for_static_assets,
+                ],
+            user_name="SRVUSR-" + app_name + "_" + environment + "_iac",
+        )
+
+        # S3 Code bucket permissions
         if s3_code_bucket_name:
-            service_user.add_managed_policy(
+            self._service_user.add_managed_policy(
                 _iam.ManagedPolicy(
                     self,
                     "service_user_s3_code_bucket_policies",
@@ -322,8 +333,9 @@ class ServiceUserForIAC(core.Construct):
             )
 
             # S3 Assets bucket permissions
+        # S3 Assets bucket permissions
         if s3_assets_bucket_name:
-            service_user.add_managed_policy(
+            self._service_user.add_managed_policy(
                 _iam.ManagedPolicy(
                     self,
                     "service_user_s3_assets_bucket_policies",
@@ -339,13 +351,3 @@ class ServiceUserForIAC(core.Construct):
                 )
             )
 
-        # Service user
-        self._service_user = _iam.User(
-            self,
-            "service_user",
-            managed_policies=[
-                managed_policy_for_iac,
-                managed_policy_for_static_assets,
-                ],
-            user_name="SRVUSR-" + app_name + "_" + environment + "_iac",
-        )
